@@ -6,6 +6,26 @@ import numpy as np
 import pandas as pd
 
 
+def date_check(df_historical, history_dates, frequency):
+    '''
+    Check that the length of the dates are correct
+    '''
+    min_date = history_dates.min()
+    last_date = history_dates.max()
+    check_dates = pd.date_range(
+        start=min_date,
+        end=last_date,
+        freq=frequency,
+    )
+    expected_dates = set(check_dates.unique())
+    given_dates = set(df_historical["ds"].unique())
+    remaining_dates = expected_dates.difference(given_dates)
+    if len(check_dates) != len(df_historical["ds"]):
+        raise Exception("The series starts on " + str(min_date) + " and ends on " + str(last_date) +
+                " the length of the series is expected to be " + str(len(check_dates)) + ", but " + str(len(df_historical["ds"])) + " was found ")
+
+
+
 class Naive(object):
     """
     Naive Forecaster
@@ -15,10 +35,9 @@ class Naive(object):
         self,
         history_dates=None,
         stan_backend=None,
-        include_history=False,
         y=None,
     ):
-        self.include_history = include_history
+        self.stan_backend = stan_backend
 
     def predict(
         self,
@@ -27,7 +46,7 @@ class Naive(object):
         frequency="D",
         lag=1,
         uncertainty_samples=5000,
-        include_history=False,
+        quiet=False,
     ):
         self.history_dates = pd.to_datetime(
             pd.Series(df_historical["ds"].unique(), name="ds")
@@ -36,19 +55,7 @@ class Naive(object):
         if self.history_dates is None:
             raise Exception("Please include historical observations.")
         last_date = self.history_dates.max()
-        min_date = self.history_dates.min()
-        check_dates = pd.date_range(
-            start=min_date,
-            end=last_date,  # An extra in case we include start
-            freq=frequency,
-        )  # 'M','D', etc.
-        expected_dates = set(check_dates.unique())
-        given_dates = set(df_historical["ds"].unique())
-        remaining_dates = expected_dates.difference(given_dates)
-        #print(remaining_dates)
-        if len(check_dates) != len(df_historical["ds"]):
-            raise Exception("The series starts on " + str(min_date) + " and ends on " + str(last_date) +
-                    " the length of the series is expected to be " + str(len(check_dates)) + ", but " + str(len(df_historical["ds"])) + " was found ")
+        date_check(df_historical, self.history_dates, frequency)
         dates = pd.date_range(
             start=last_date,
             periods=horizon + 1,  # An extra in case we include start
@@ -56,8 +63,6 @@ class Naive(object):
         )  # 'M','D', etc.
         dates = dates[dates > last_date]  # Drop start if equals last_date
         dates = dates[:horizon]  # Return correct number of periods
-        if include_history:
-            dates = np.concatenate((np.array(self.history_dates), dates))
         df_dates = pd.DataFrame({"ds": dates})
         df_samples = pd.DataFrame({"rep": np.arange(uncertainty_samples)})
         df_cross = df_dates.merge(df_samples, how="cross")
@@ -78,7 +83,8 @@ class Naive(object):
         np_predictions = (
             df_fit.to_numpy().transpose().reshape(uncertainty_samples * horizon, 1)
         )
-        print(fit.summary())
+        if quiet is False:
+            print(fit.summary())
         df_pred = pd.DataFrame(np_predictions, columns=["y_sim"])
         df_result = pd.concat([df_cross, df_pred], axis=1)
         return df_result
@@ -93,18 +99,16 @@ class Mean(object):
         self,
         history_dates=None,
         stan_backend=None,
-        include_history=False,
         y=None,
     ):
-        self.include_history = include_history
-
+        self.stan_backend = stan_backend
     def predict(
         self,
         df_historical,
         horizon=30,
         frequency="D",
         uncertainty_samples=5000,
-        include_history=False,
+        quiet=False
     ):
         self.history_dates = pd.to_datetime(
             pd.Series(df_historical["ds"].unique(), name="ds")
@@ -113,19 +117,7 @@ class Mean(object):
         if self.history_dates is None:
             raise Exception("Please include historical observations.")
         last_date = self.history_dates.max()
-        min_date = self.history_dates.min()
-        check_dates = pd.date_range(
-            start=min_date,
-            end=last_date,  # An extra in case we include start
-            freq=frequency,
-        )  # 'M','D', etc.
-        expected_dates = set(check_dates.unique())
-        given_dates = set(df_historical["ds"].unique())
-        remaining_dates = expected_dates.difference(given_dates)
-        #print(remaining_dates)
-        if len(check_dates) != len(df_historical["ds"]):
-            raise Exception("The series starts on " + str(min_date) + " and ends on " + str(last_date) +
-                    " the length of the series is expected to be " + str(len(check_dates)) + ", but " + str(len(df_historical["ds"])) + " was found ")
+        date_check(df_historical, self.history_dates, frequency)
         dates = pd.date_range(
             start=last_date,
             periods=horizon + 1,  # An extra in case we include start
@@ -133,8 +125,6 @@ class Mean(object):
         )  # 'M','D', etc.
         dates = dates[dates > last_date]  # Drop start if equals last_date
         dates = dates[:horizon]  # Return correct number of periods
-        if include_history:
-            dates = np.concatenate((np.array(self.history_dates), dates))
         df_dates = pd.DataFrame({"ds": dates})
         df_samples = pd.DataFrame({"rep": np.arange(uncertainty_samples)})
         df_cross = df_dates.merge(df_samples, how="cross")
@@ -155,7 +145,8 @@ class Mean(object):
         np_predictions = (
             df_fit.to_numpy().transpose().reshape(uncertainty_samples * horizon, 1)
         )
-        print(fit.summary())
+        if quiet is False:
+            print(fit.summary())
         df_pred = pd.DataFrame(np_predictions, columns=["y_sim"])
         df_result = pd.concat([df_cross, df_pred], axis=1)
         return df_result
@@ -170,10 +161,9 @@ class Snaive(object):
         self,
         history_dates=None,
         stan_backend=None,
-        include_history=False,
         y=None,
     ):
-        self.include_history = include_history
+        self.stan_backend = stan_backend 
 
     def predict(
         self,
@@ -183,6 +173,7 @@ class Snaive(object):
         lag=7,
         uncertainty_samples=5000,
         include_history=False,
+        quiet=False
     ):
         self.history_dates = pd.to_datetime(
             pd.Series(df_historical["ds"].unique(), name="ds")
@@ -191,19 +182,7 @@ class Snaive(object):
         if self.history_dates is None:
             raise Exception("Please include historical observations.")
         last_date = self.history_dates.max()
-        min_date = self.history_dates.min()
-        check_dates = pd.date_range(
-            start=min_date,
-            end=last_date,  # An extra in case we include start
-            freq=frequency,
-        )  # 'M','D', etc.
-        expected_dates = set(check_dates.unique())
-        given_dates = set(df_historical["ds"].unique())
-        remaining_dates = expected_dates.difference(given_dates)
-        #print(remaining_dates)
-        if len(check_dates) != len(df_historical["ds"]):
-            raise Exception("The series starts on " + str(min_date) + " and ends on " + str(last_date) +
-                    " the length of the series is expected to be " + str(len(check_dates)) + ", but " + str(len(df_historical["ds"])) + " was found ")
+        date_check(df_historical, self.history_dates, frequency)
         dates = pd.date_range(
             start=last_date,
             periods=horizon + 1,  # An extra in case we include start
@@ -233,7 +212,8 @@ class Snaive(object):
         np_predictions = (
             df_fit.to_numpy().transpose().reshape(uncertainty_samples * horizon, 1)
         )
-        print(fit.summary())
+        if quiet is False:
+            print(fit.summary())
         df_pred = pd.DataFrame(np_predictions, columns=["y_sim"])
         df_result = pd.concat([df_cross, df_pred], axis=1)
         return df_result
